@@ -1,5 +1,5 @@
-#  tests for pyproj-1.9.5.1-py37h1fcc0e4_1007 (this is a generated file);
-print('===== testing package: pyproj-1.9.5.1-py37h1fcc0e4_1007 =====');
+#  tests for pyproj-1.9.6-py37h1fcc0e4_1000 (this is a generated file);
+print('===== testing package: pyproj-1.9.6-py37h1fcc0e4_1000 =====');
 print('running run_test.py');
 #  --- run_test.py (begin) ---
 import os
@@ -15,7 +15,7 @@ Proj(init='epsg:4269')
 if not os.path.isdir(pyproj.pyproj_datadir):
     sys.exit(1)#  --- run_test.py (end) ---
 
-print('===== pyproj-1.9.5.1-py37h1fcc0e4_1007 OK =====');
+print('===== pyproj-1.9.6-py37h1fcc0e4_1000 OK =====');
 print("import: 'pyproj'")
 import pyproj
 
